Export Package VRC : bc - bc B61Ma cn30
Update compared VRC:   B61 a cn30
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : Yes
Library sources    : No
Creation Date      : 112417 17:03:19
Total file size    : 2216387
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
S = Subscription Templates
b = Functions
A = Additional Files
h = Help Text Codes
Q = SQL Queries
P = Customization Projects
----------------------
dbcdmp.stat                                           B61Ma cn30 (not expired)
dbcgct.dbse                                           B61Ma cn30 (not expired)
dbcgen.db                                             B61Ma cn30 (not expired)
dbcgen.str4                                           B61Ma cn30 (not expired)
dbcldr.loadtype                                       B61Ma cn30 (not expired)
dbcldr.stat                                           B61Ma cn30 (not expired)
dbcperc                                               B61Ma cn30 (not expired)
dbcpid                                                B61Ma cn30 (not expired)
tbcdmp000                                             B61Ma cn30 (not expired)
tbcdmp987                                             B61Ma cn30 (not expired)
tbcgct005                                             B61Ma cn30 (not expired)
tbcgct305                                             B61Ma cn30 (not expired)
tbcrun888                                             B61Ma cn30 (not expired)
sbccnv0205m000                                        B61Ma cn30 (not expired)
sbccnv2101m000                                        B61Ma cn30 (not expired)
sbccnv2201m000                                        B61Ma cn30 (not expired)
sbccnv2201m001                                        B61Ma cn30 (not expired)
sbccnv4500m000                                        B61Ma cn30 (not expired)
sbccnv4501m000                                        B61Ma cn30 (not expired)
sbccnv4502m000                                        B61Ma cn30 (not expired)
sbccnv5101m000                                        B61Ma cn30 (not expired)
sbccnv5200m000                                        B61Ma cn30 (not expired)
sbccnv5201s000                                        B61Ma cn30 (not expired)
sbccnv5202m000                                        B61Ma cn30 (not expired)
sbccnv5400s000                                        B61Ma cn30 (not expired)
sbccnv5402s000                                        B61Ma cn30 (not expired)
sbccnv5405s000                                        B61Ma cn30 (not expired)
sbccnv5406s000                                        B61Ma cn30 (not expired)
sbccnv5471m000                                        B61Ma cn30 (not expired)
sbccnv5500m000                                        B61Ma cn30 (not expired)
sbccnv5500m001                                        B61Ma cn30 (not expired)
sbccnv5571m000                                        B61Ma cn30 (not expired)
sbccnv9290m000                                        B61Ma cn30 (not expired)
sbccnv9290s002                                        B61Ma cn30 (not expired)
sbccnv9291s002                                        B61Ma cn30 (not expired)
sbccnv9442m000                                        B61Ma cn30 (not expired)
sbcdmp0100m000                                        B61Ma cn30 (not expired)
sbcdmp0103m000                                        B61Ma cn30 (not expired)
sbcdmp0105s000                                        B61Ma cn30 (not expired)
sbcdmp0106m000                                        B61Ma cn30 (not expired)
sbcdmp0107m000                                        B61Ma cn30 (not expired)
sbcdmp0200s000                                        B61Ma cn30 (not expired)
sbcdmp0203s000                                        B61Ma cn30 (not expired)
sbcdmp4220m000                                        B61Ma cn30 (not expired)
sbcdmp4520m000                                        B61Ma cn30 (not expired)
sbcdmp5100m000                                        B61Ma cn30 (not expired)
sbcdmp5106m000                                        B61Ma cn30 (not expired)
sbcdmp5201m000                                        B61Ma cn30 (not expired)
sbcdmp5300m000                                        B61Ma cn30 (not expired)
sbcdmp5301m000                                        B61Ma cn30 (not expired)
sbcdmp5401m000                                        B61Ma cn30 (not expired)
sbcdmp5404m000                                        B61Ma cn30 (not expired)
sbcdmp5406m000                                        B61Ma cn30 (not expired)
sbcdmp5500m000                                        B61Ma cn30 (not expired)
sbcdmp5501m000                                        B61Ma cn30 (not expired)
sbcdmp5503m000                                        B61Ma cn30 (not expired)
sbcdmp6400m000                                        B61Ma cn30 (not expired)
sbcdmp8101m000                                        B61Ma cn30 (not expired)
sbcdmp8201s000                                        B61Ma cn30 (not expired)
sbcdmp8201s002                                        B61Ma cn30 (not expired)
sbcdmp8203m000                                        B61Ma cn30 (not expired)
sbcdmp8502m000                                        B61Ma cn30 (not expired)
sbcdmp8503m000                                        B61Ma cn30 (not expired)
sbcdmp8503s002                                        B61Ma cn30 (not expired)
sbcdmp8506s000                                        B61Ma cn30 (not expired)
sbcdmp8507s000                                        B61Ma cn30 (not expired)
sbcdmp8508s000                                        B61Ma cn30 (not expired)
sbcdmp8570m000                                        B61Ma cn30 (not expired)
sbcdmp8571m000                                        B61Ma cn30 (not expired)
sbcdmp8572m000                                        B61Ma cn30 (not expired)
sbcdmp9087m000                                        B61Ma cn30 (not expired)
sbcdmp9100m000                                        B61Ma cn30 (not expired)
sbcdmp9188m000                                        B61Ma cn30 (not expired)
sbcdmp9189m000                                        B61Ma cn30 (not expired)
sbcdmp9190m000                                        B61Ma cn30 (not expired)
sbcdmp9191m000                                        B61Ma cn30 (not expired)
sbcdmp9288m000                                        B61Ma cn30 (not expired)
sbcdmp9291m100                                        B61Ma cn30 (not expired)
sbcdmp9291m200                                        B61Ma cn30 (not expired)
sbcdmp9442m000                                        B61Ma cn30 (not expired)
sbcdmp9585m000                                        B61Ma cn30 (not expired)
sbcdmp9599m000                                        B61Ma cn30 (not expired)
sbcdmpdebug                                           B61Ma cn30 (not expired)
sbcgct0100m000                                        B61Ma cn30 (not expired)
sbcgct3101m000                                        B61Ma cn30 (not expired)
sbcgct3102m000                                        B61Ma cn30 (not expired)
sbcgct3103m000                                        B61Ma cn30 (not expired)
sbcgct3105m000                                        B61Ma cn30 (not expired)
sbcgct4500m000                                        B61Ma cn30 (not expired)
sbcgct4501m000                                        B61Ma cn30 (not expired)
sbcgct4502m000                                        B61Ma cn30 (not expired)
sbcgct6100m000                                        B61Ma cn30 (not expired)
sbcgct6100s100                                        B61Ma cn30 (not expired)
sbcgct6101m000                                        B61Ma cn30 (not expired)
sbcgct7186m000                                        B61Ma cn30 (not expired)
sbcgct7286m000                                        B61Ma cn30 (not expired)
sbcgct8188m000                                        B61Ma cn30 (not expired)
sbcgct8189m000                                        B61Ma cn30 (not expired)
sbcgct8283m000                                        B61Ma cn30 (not expired)
sbcgct8288m000                                        B61Ma cn30 (not expired)
sbcgct8289m000                                        B61Ma cn30 (not expired)
sbcgct8489m000                                        B61Ma cn30 (not expired)
sbcgct9188m000                                        B61Ma cn30 (not expired)
sbcgct9189m000                                        B61Ma cn30 (not expired)
sbcgct9285m000                                        B61Ma cn30 (not expired)
sbcgct9289m000                                        B61Ma cn30 (not expired)
sbcgcteasym000                                        B61Ma cn30 (not expired)
sbcgctmysql                                           B61Ma cn30 (not expired)
sbcgctoracle                                          B61Ma cn30 (not expired)
sbcgen9200m000                                        B61Ma cn30 (not expired)
sbcldr9100m000                                        B61Ma cn30 (not expired)
sbcrun0000m000                                        B61Ma cn30 (not expired)
sbcrun0207m000                                        B61Ma cn30 (not expired)
sbcrun0507m000                                        B61Ma cn30 (not expired)
sbcrun8288m000                                        B61Ma cn30 (not expired)
sbcrun8588m000                                        B61Ma cn30 (not expired)
sbcrun9599m000                                        B61Ma cn30 (not expired)
sbcruntdsls400                                        B61Ma cn30 (not expired)
pbccnv2201                                            B61Ma cn30 (without source) (not expired)
pbccnv5200                                            B61Ma cn30 (without source) (not expired)
pbccnv5201                                            B61Ma cn30 (without source) (not expired)
pbccnv5402                                            B61Ma cn30 (without source) (not expired)
pbccnv5405                                            B61Ma cn30 (without source) (not expired)
pbccnv5406                                            B61Ma cn30 (without source) (not expired)
pbccnv9190                                            B61Ma cn30 (without source) (not expired)
pbccnvloganalys                                       B61Ma cn30 (without source) (not expired)
pbccnvtext                                            B61Ma cn30 (without source) (not expired)
pbcdmp000                                             B61Ma cn30 (without source) (not expired)
pbcdmp0100                                            B61Ma cn30 (without source) (not expired)
pbcdmp0107                                            B61Ma cn30 (without source) (not expired)
pbcdmp801run                                          B61Ma cn30 (without source) (not expired)
pbcdmp8211                                            B61Ma cn30 (without source) (not expired)
pbcdmp9087                                            B61Ma cn30 (without source) (not expired)
pbcdmp9100                                            B61Ma cn30 (without source) (not expired)
pbcdmp9188                                            B61Ma cn30 (without source) (not expired)
pbcdmp91881                                           B61Ma cn30 (without source) (not expired)
pbcdmpdebug                                           B61Ma cn30 (without source) (not expired)
pbcdmpdllcommon                                       B61Ma cn30 (without source) (not expired)
pbcdmpdlldca                                          B61Ma cn30 (without source) (not expired)
pbcdmpinitrep                                         B61Ma cn30 (without source) (not expired)
pbcgct000                                             B61Ma cn30 (without source) (not expired)
pbcgct0100                                            B61Ma cn30 (without source) (not expired)
pbcgct1552                                            B61Ma cn30 (without source) (not expired)
pbcgct305                                             B61Ma cn30 (without source) (not expired)
pbcgct3101                                            B61Ma cn30 (without source) (not expired)
pbcgct3102                                            B61Ma cn30 (without source) (not expired)
pbcgct3105                                            B61Ma cn30 (without source) (not expired)
pbcgct3gldca                                          B61Ma cn30 (without source) (not expired)
pbcgct6100                                            B61Ma cn30 (without source) (not expired)
pbcgct7186                                            B61Ma cn30 (without source) (not expired)
pbcgct8189                                            B61Ma cn30 (without source) (not expired)
pbcgct8289                                            B61Ma cn30 (without source) (not expired)
pbcgct9188                                            B61Ma cn30 (without source) (expired)
pbcgct9289                                            B61Ma cn30 (without source) (not expired)
pbcgct989                                             B61Ma cn30 (without source) (not expired)
pbcgctdllcommon                                       B61Ma cn30 (without source) (not expired)
pbcgctdlldca                                          B61Ma cn30 (without source) (not expired)
pbcgctdllmail                                         B61Ma cn30 (without source) (not expired)
pbcgctdllsca                                          B61Ma cn30 (without source) (not expired)
pbcgcteasy                                            B61Ma cn30 (without source) (not expired)
pbcgctmigwizard                                       B61Ma cn30 (without source) (not expired)
pbcgctntdll                                           B61Ma cn30 (without source) (not expired)
pbcgctoracle                                          B61Ma cn30 (without source) (not expired)
pbcgen9200                                            B61Ma cn30 (without source) (not expired)
pbcgen9201                                            B61Ma cn30 (without source) (not expired)
pbcgenntdll                                           B61Ma cn30 (without source) (not expired)
pbcgentimer                                           B61Ma cn30 (without source) (not expired)
pbcintdll0000                                         B61Ma cn30 (without source) (not expired)
pbcintdll0001                                         B61Ma cn30 (without source) (not expired)
pbcldr9100                                            B61Ma cn30 (without source) (not expired)
pbcrun8288                                            B61Ma cn30 (without source) (not expired)
pbcrun8588                                            B61Ma cn30 (without source) (not expired)
pbcrun90501                                           B61Ma cn30 (without source) (not expired)
pbcrun90502                                           B61Ma cn30 (without source) (not expired)
pbcrun90504                                           B61Ma cn30 (without source) (not expired)
pbcrun90505                                           B61Ma cn30 (without source) (not expired)
pbcrun90506                                           B61Ma cn30 (without source) (not expired)
pbcrun90507                                           B61Ma cn30 (without source) (not expired)
pbcrun90508                                           B61Ma cn30 (without source) (not expired)
pbcrun9599                                            B61Ma cn30 (without source) (not expired)
pbcruncommon                                          B61Ma cn30 (without source) (not expired)
pbcrunconvdll                                         B61Ma cn30 (without source) (not expired)
pbcrunconvdllts                                       B61Ma cn30 (without source) (not expired)
pbcrundalload                                         B61Ma cn30 (without source) (not expired)
pbcrundbload                                          B61Ma cn30 (without source) (not expired)
pbcrundll000001                                       B61Ma cn30 (without source) (not expired)
pbcrundll000002                                       B61Ma cn30 (without source) (not expired)
pbcrundll0200                                         B61Ma cn30 (without source) (not expired)
pbcrundllcommon                                       B61Ma cn30 (without source) (not expired)
pbcrundllconect                                       B61Ma cn30 (without source) (not expired)
pbcrundlldb2                                          B61Ma cn30 (without source) (not expired)
pbcrundlledb                                          B61Ma cn30 (without source) (not expired)
pbcrundllmssql                                        B61Ma cn30 (without source) (not expired)
fbccnv0205m000d2                                      B61Ma cn30 (not expired)
fbccnv2101m000d2                                      B61Ma cn30 (not expired)
fbccnv2201m000d2                                      B61Ma cn30 (not expired)
fbccnv2201m001d2                                      B61Ma cn30 (not expired)
fbccnv4500m000d2                                      B61Ma cn30 (not expired)
fbccnv4501m000d2                                      B61Ma cn30 (not expired)
fbccnv4502m000d2                                      B61Ma cn30 (not expired)
fbccnv5101m000d2                                      B61Ma cn30 (not expired)
fbccnv5200m000d2                                      B61Ma cn30 (not expired)
fbccnv5201s000d2                                      B61Ma cn30 (not expired)
fbccnv5202m000d2                                      B61Ma cn30 (not expired)
fbccnv5400s000d2                                      B61Ma cn30 (not expired)
fbccnv5402s000d2                                      B61Ma cn30 (not expired)
fbccnv5405s000d2                                      B61Ma cn30 (not expired)
fbccnv5406s000d2                                      B61Ma cn30 (not expired)
fbccnv5471m000d2                                      B61Ma cn30 (not expired)
fbccnv5500m000d2                                      B61Ma cn30 (not expired)
fbccnv5500m001d2                                      B61Ma cn30 (not expired)
fbccnv5571m000d2                                      B61Ma cn30 (not expired)
fbccnv9290m000d2                                      B61Ma cn30 (not expired)
fbccnv9290s002d2                                      B61Ma cn30 (not expired)
fbccnv9291s002d2                                      B61Ma cn30 (not expired)
fbccnv9442m000d2                                      B61Ma cn30 (not expired)
fbcdmp0100m000d2                                      B61Ma cn30 (not expired)
fbcdmp0103m000d2                                      B61Ma cn30 (not expired)
fbcdmp0105s000d2                                      B61Ma cn30 (not expired)
fbcdmp0106m000d2                                      B61Ma cn30 (not expired)
fbcdmp0107m000d2                                      B61Ma cn30 (not expired)
fbcdmp0200s000d2                                      B61Ma cn30 (not expired)
fbcdmp0203s000d2                                      B61Ma cn30 (not expired)
fbcdmp4220m000d2                                      B61Ma cn30 (not expired)
fbcdmp4520m000d2                                      B61Ma cn30 (not expired)
fbcdmp5100m000d2                                      B61Ma cn30 (not expired)
fbcdmp5106m000d2                                      B61Ma cn30 (not expired)
fbcdmp5201m000d2                                      B61Ma cn30 (not expired)
fbcdmp5300m000d2                                      B61Ma cn30 (not expired)
fbcdmp5301m000d2                                      B61Ma cn30 (not expired)
fbcdmp5401m000d2                                      B61Ma cn30 (not expired)
fbcdmp5404m000d2                                      B61Ma cn30 (not expired)
fbcdmp5406m000d2                                      B61Ma cn30 (not expired)
fbcdmp5500m000d2                                      B61Ma cn30 (not expired)
fbcdmp5501m000d2                                      B61Ma cn30 (not expired)
fbcdmp5503m000d2                                      B61Ma cn30 (not expired)
fbcdmp6400m000d2                                      B61Ma cn30 (not expired)
fbcdmp8101m000d2                                      B61Ma cn30 (not expired)
fbcdmp8201s000d2                                      B61Ma cn30 (not expired)
fbcdmp8201s002d2                                      B61Ma cn30 (not expired)
fbcdmp8203m000d2                                      B61Ma cn30 (not expired)
fbcdmp8502m000d2                                      B61Ma cn30 (not expired)
fbcdmp8503m000d2                                      B61Ma cn30 (not expired)
fbcdmp8503s002d2                                      B61Ma cn30 (not expired)
fbcdmp8506s000d2                                      B61Ma cn30 (not expired)
fbcdmp8507s000d2                                      B61Ma cn30 (not expired)
fbcdmp8508s000d2                                      B61Ma cn30 (not expired)
fbcdmp8570m000d2                                      B61Ma cn30 (not expired)
fbcdmp8571m000d2                                      B61Ma cn30 (not expired)
fbcdmp8572m000d2                                      B61Ma cn30 (not expired)
fbcdmp9087m000d2                                      B61Ma cn30 (not expired)
fbcdmp9100m000d2                                      B61Ma cn30 (not expired)
fbcdmp9188m000d2                                      B61Ma cn30 (not expired)
fbcdmp9189m000d2                                      B61Ma cn30 (not expired)
fbcdmp9190m000d2                                      B61Ma cn30 (not expired)
fbcdmp9191m000d2                                      B61Ma cn30 (not expired)
fbcdmp9288m000d2                                      B61Ma cn30 (not expired)
fbcdmp9291m100d2                                      B61Ma cn30 (not expired)
fbcdmp9291m200d2                                      B61Ma cn30 (not expired)
fbcdmp9442m000d2                                      B61Ma cn30 (not expired)
fbcdmp9585m000d2                                      B61Ma cn30 (not expired)
fbcdmp9599m000d2                                      B61Ma cn30 (not expired)
fbcdmpdebugd   2                                      B61Ma cn30 (not expired)
fbcgct0100m000d2                                      B61Ma cn30 (not expired)
fbcgct3101m000d2                                      B61Ma cn30 (not expired)
fbcgct3102m000d2                                      B61Ma cn30 (not expired)
fbcgct3103m000d2                                      B61Ma cn30 (not expired)
fbcgct3105m000d2                                      B61Ma cn30 (not expired)
fbcgct4500m000d2                                      B61Ma cn30 (not expired)
fbcgct4501m000d2                                      B61Ma cn30 (not expired)
fbcgct4502m000d2                                      B61Ma cn30 (not expired)
fbcgct6100m000d2                                      B61Ma cn30 (not expired)
fbcgct6100s100d2                                      B61Ma cn30 (not expired)
fbcgct6101m000d2                                      B61Ma cn30 (not expired)
fbcgct7186m000d2                                      B61Ma cn30 (not expired)
fbcgct7286m000d2                                      B61Ma cn30 (not expired)
fbcgct8188m000d2                                      B61Ma cn30 (not expired)
fbcgct8189m000d2                                      B61Ma cn30 (not expired)
fbcgct8283m000d2                                      B61Ma cn30 (not expired)
fbcgct8288m000d2                                      B61Ma cn30 (not expired)
fbcgct8289m000d2                                      B61Ma cn30 (not expired)
fbcgct8489m000d2                                      B61Ma cn30 (not expired)
fbcgct9188m000d2                                      B61Ma cn30 (not expired)
fbcgct9189m000d2                                      B61Ma cn30 (not expired)
fbcgct9285m000d2                                      B61Ma cn30 (not expired)
fbcgct9289m000d2                                      B61Ma cn30 (not expired)
fbcgcteasym000d2                                      B61Ma cn30 (not expired)
fbcgctmysqld   2                                      B61Ma cn30 (not expired)
fbcgctoracled  2                                      B61Ma cn30 (not expired)
fbcgen9200m000d2                                      B61Ma cn30 (not expired)
fbcldr9100m000d2                                      B61Ma cn30 (not expired)
fbcrun0000m000d2                                      B61Ma cn30 (not expired)
fbcrun0207m000d2                                      B61Ma cn30 (not expired)
fbcrun0507m000d2                                      B61Ma cn30 (not expired)
fbcrun8288m000d2                                      B61Ma cn30 (not expired)
fbcrun8588m000d2                                      B61Ma cn30 (not expired)
fbcrun9599m000d2                                      B61Ma cn30 (not expired)
fbcruntdsls400d2                                      B61Ma cn30 (not expired)
rbcgct0100110002                                      B61Ma cn30 (not expired)
cbcgencommon.e                                        B61Ma cn30 (not expired)
cbcgencommon.s                                        B61Ma cn30 (not expired)
bbcbic___slm___                                       B61Ma cn30 (with source) (not expired)
bbcgencommon                                          B61Ma cn30 (with source) (not expired)
bbcruncommon                                          B61Ma cn30 (with source) (not expired)
bbcrundefines                                         B61Ma cn30 (with source) (not expired)
bbcrunedb                                             B61Ma cn30 (with source) (not expired)
bbcrunoracle                                          B61Ma cn30 (with source) (not expired)
obccnv2201                                            B61Ma cn30
obccnv5200                                            B61Ma cn30
obccnv5201                                            B61Ma cn30
obccnv5402                                            B61Ma cn30
obccnv5405                                            B61Ma cn30
obccnv5406                                            B61Ma cn30
obccnv9190                                            B61Ma cn30
obccnvloganalys                                       B61Ma cn30
obccnvtext                                            B61Ma cn30
obcdllftttxt010                                       B61Ma cn30
obcdmp000                                             B61Ma cn30
obcdmp0100                                            B61Ma cn30
obcdmp0107                                            B61Ma cn30
obcdmp5300                                            B61Ma cn30
obcdmp5301                                            B61Ma cn30
obcdmp5404                                            B61Ma cn30
obcdmp5406                                            B61Ma cn30
obcdmp6400                                            B61Ma cn30
obcdmp801run                                          B61Ma cn30
obcdmp8211                                            B61Ma cn30
obcdmp9087                                            B61Ma cn30
obcdmp9100                                            B61Ma cn30
obcdmp9188                                            B61Ma cn30
obcdmp91881                                           B61Ma cn30
obcdmpdebug                                           B61Ma cn30
obcdmpdllcommon                                       B61Ma cn30
obcdmpdlldca                                          B61Ma cn30
obcdmpinitrep                                         B61Ma cn30
obcdmploganalys                                       B61Ma cn30
obcdmpnttest                                          B61Ma cn30
obcgct000                                             B61Ma cn30
obcgct0100                                            B61Ma cn30
obcgct1552                                            B61Ma cn30
obcgct305                                             B61Ma cn30
obcgct3101                                            B61Ma cn30
obcgct3102                                            B61Ma cn30
obcgct3105                                            B61Ma cn30
obcgct3gldca                                          B61Ma cn30
obcgct6100                                            B61Ma cn30
obcgct7186                                            B61Ma cn30
obcgct8189                                            B61Ma cn30
obcgct8289                                            B61Ma cn30
obcgct9188                                            B61Ma cn30
obcgct9289                                            B61Ma cn30
obcgct989                                             B61Ma cn30
obcgctdllcommon                                       B61Ma cn30
obcgctdlldca                                          B61Ma cn30
obcgctdllmail                                         B61Ma cn30
obcgctdllsca                                          B61Ma cn30
obcgcteasy                                            B61Ma cn30
obcgctmigwizard                                       B61Ma cn30
obcgctntdll                                           B61Ma cn30
obcgctoracle                                          B61Ma cn30
obcgen9200                                            B61Ma cn30
obcgen9201                                            B61Ma cn30
obcgenntdll                                           B61Ma cn30
obcgentimer                                           B61Ma cn30
obcintdll0000                                         B61Ma cn30
obcintdll0001                                         B61Ma cn30
obcldr9100                                            B61Ma cn30
obcrun8288                                            B61Ma cn30
obcrun8588                                            B61Ma cn30
obcrun90501                                           B61Ma cn30
obcrun90502                                           B61Ma cn30
obcrun90504                                           B61Ma cn30
obcrun90505                                           B61Ma cn30
obcrun90506                                           B61Ma cn30
obcrun90507                                           B61Ma cn30
obcrun90508                                           B61Ma cn30
obcrun9599                                            B61Ma cn30
obcruncommon                                          B61Ma cn30
obcrunconvdll                                         B61Ma cn30
obcrunconvdllts                                       B61Ma cn30
obcrundalload                                         B61Ma cn30
obcrundbload                                          B61Ma cn30
obcrundll000001                                       B61Ma cn30
obcrundll000002                                       B61Ma cn30
obcrundll0200                                         B61Ma cn30
obcrundllcommon                                       B61Ma cn30
obcrundllconect                                       B61Ma cn30
obcrundlldb2                                          B61Ma cn30
obcrundlledb                                          B61Ma cn30
obcrundllinform                                       B61Ma cn30
obcrundllmssql                                        B61Ma cn30
obcrundllmysql                                        B61Ma cn30
obcrundlloracle                                       B61Ma cn30
obcrunonpload                                         B61Ma cn30
obcruntext                                            B61Ma cn30
obcgct0100110002                                      B61Ma cn30
lbcbcdmp000.ituf    122                               B61Ma cn30 (not expired)
lbcbcdmp9188.05     127                               B61Ma cn30 (not expired)
lbcbcdmp9188.06     127                               B61Ma cn30 (not expired)
lbcbcdmp988.repf    114                               B61Ma cn30 (not expired)
lbcbcdmp988.repf    115                               B61Ma cn30 (expired)
lbcbcgct.sour       123                               B61Ma cn30 (not expired)
lbcbcgct.updtblinfo 131                               B61Ma cn30 (not expired)
lbcbcgct305.dnam    117                               B61Ma cn30 (not expired)
lbcbcgct305.dsch    119                               B61Ma cn30 (not expired)
lbcbcgct305.dusr    108                               B61Ma cn30 (not expired)
lbcbcgct305.isdr    121                               B61Ma cn30 (not expired)
lbcbcgcteasy.26     109                               B61Ma cn30 (not expired)
lbcbcgcteasy.27     111                               B61Ma cn30 (not expired)
lbcdmp.debug        105                               B61Ma cn30 (not expired)
lbcdmp.label.503    126                               B61Ma cn30 (not expired)
lbcdmp.rec.dumped   114                               B61Ma cn30 (not expired)
lbcdmp.reset        113                               B61Ma cn30 (not expired)
lbcdmp.resume       114                               B61Ma cn30 (not expired)
lbcdmp.rmv.datafiles117                               B61Ma cn30 (not expired)
lbcdmp.start        113                               B61Ma cn30 (not expired)
lbcdmp.stat001      105                               B61Ma cn30 (not expired)
lbcdmp.stat002      107                               B61Ma cn30 (not expired)
lbcdmp.stat003      107                               B61Ma cn30 (not expired)
lbcdmp.stat004      109                               B61Ma cn30 (not expired)
lbcdmp.stat005      109                               B61Ma cn30 (not expired)
lbcdmp.stat006      101                               B61Ma cn30 (not expired)
lbcdmp.stop         112                               B61Ma cn30 (not expired)
lbcdmp0105s000001   126                               B61Ma cn30 (not expired)
lbcdmp9100m000001   114                               B61Ma cn30 (not expired)
lbcdumped           106                               B61Ma cn30 (not expired)
lbcgct.dbse022      103                               B61Ma cn30 (not expired)
lbcgct00502001      118                               B61Ma cn30 (not expired)
lbcgct00503001      135                               B61Ma cn30 (not expired)
lbcgct0305001       132                               B61Ma cn30 (not expired)
lbcgct305001        122                               B61Ma cn30 (not expired)
lbcgct30501001      115                               B61Ma cn30 (not expired)
lbcgct3105m000001   132                               B61Ma cn30 (not expired)
lbcgcteasym000001   119                               B61Ma cn30 (not expired)
lbcgen.add          103                               B61Ma cn30 (not expired)
lbcgen.comp.nr      114                               B61Ma cn30 (not expired)
lbcgen.db001        114                               B61Ma cn30 (not expired)
lbcgen.db002        106                               B61Ma cn30 (not expired)
lbcgen.db003        113                               B61Ma cn30 (not expired)
lbcgen.db004        103                               B61Ma cn30 (not expired)
lbcgen.db005        108                               B61Ma cn30 (not expired)
lbcgen.db006        106                               B61Ma cn30 (not expired)
lbcgen.db007        114                               B61Ma cn30 (not expired)
lbcgen.file.path    109                               B61Ma cn30 (not expired)
lbcgen.finish       106                               B61Ma cn30 (not expired)
lbcgen.nr.of.process111                               B61Ma cn30 (not expired)
lbcgen.remove       106                               B61Ma cn30 (not expired)
lbcgen.seqn         104                               B61Ma cn30 (not expired)
lbcgen.seqn         108                               B61Ma cn30 (not expired)
lbcgen.start        105                               B61Ma cn30 (not expired)
lbcgen.start.seqn   114                               B61Ma cn30 (not expired)
lbcgen.start.sess   113                               B61Ma cn30 (not expired)
lbcgen.started      108                               B61Ma cn30 (not expired)
lbcgtc0100.07       105                               B61Ma cn30 (not expired)
lbcisotable         109                               B61Ma cn30 (not expired)
lbcldr.add.process  111                               B61Ma cn30 (not expired)
lbcldr.clear.dir    123                               B61Ma cn30 (not expired)
lbcldr.load.type    109                               B61Ma cn30 (not expired)
lbcldr.loadtype001  109                               B61Ma cn30 (not expired)
lbcldr.loadtype002  115                               B61Ma cn30 (not expired)
lbcldr.resume.load  114                               B61Ma cn30 (not expired)
lbcldr.rmv.process  114                               B61Ma cn30 (not expired)
lbcldr.start.load   113                               B61Ma cn30 (not expired)
lbcldr.stat001      107                               B61Ma cn30 (not expired)
lbcldr.stat002      107                               B61Ma cn30 (not expired)
lbcldr.stat003      109                               B61Ma cn30 (not expired)
lbcldr.stat004      109                               B61Ma cn30 (not expired)
lbcldr.stat006      101                               B61Ma cn30 (not expired)
lbcldr.stat007      105                               B61Ma cn30 (not expired)
lbcldr.stop.load    112                               B61Ma cn30 (not expired)
lbcldr9100m000001   114                               B61Ma cn30 (not expired)
lbcperc.compl       119                               B61Ma cn30 (not expired)
lbctcgen.item       104                               B61Ma cn30 (not expired)
lbctcgen.seqno      108                               B61Ma cn30 (not expired)
lbctcmcs003.cwar    109                               B61Ma cn30 (not expired)
lbcwhinr100.koor    110                               B61Ma cn30 (not expired)
lbcwhinr100.kost    116                               B61Ma cn30 (not expired)
lbcwhinr100.trdt    116                               B61Ma cn30 (not expired)
Fbccnv0205m000d2                                      B61Ma cn30
Fbccnv2101m000d2                                      B61Ma cn30
Fbccnv2201m000d2                                      B61Ma cn30
Fbccnv2201m001d2                                      B61Ma cn30
Fbccnv4500m000d2                                      B61Ma cn30
Fbccnv4501m000d2                                      B61Ma cn30
Fbccnv4502m000d2                                      B61Ma cn30
Fbccnv5101m000d2                                      B61Ma cn30
Fbccnv5200m000d2                                      B61Ma cn30
Fbccnv5201s000d2                                      B61Ma cn30
Fbccnv5202m000d2                                      B61Ma cn30
Fbccnv5400s000d2                                      B61Ma cn30
Fbccnv5402s000d2                                      B61Ma cn30
Fbccnv5405s000d2                                      B61Ma cn30
Fbccnv5406s000d2                                      B61Ma cn30
Fbccnv5471m000d2                                      B61Ma cn30
Fbccnv5500m000d2                                      B61Ma cn30
Fbccnv5500m001d2                                      B61Ma cn30
Fbccnv5571m000d2                                      B61Ma cn30
Fbccnv9290m000d2                                      B61Ma cn30
Fbccnv9290s002d2                                      B61Ma cn30
Fbccnv9291s002d2                                      B61Ma cn30
Fbccnv9442m000d2                                      B61Ma cn30
Fbcdmp0100m000d2                                      B61Ma cn30
Fbcdmp0103m000d2                                      B61Ma cn30
Fbcdmp0105s000d2                                      B61Ma cn30
Fbcdmp0106m000d2                                      B61Ma cn30
Fbcdmp0107m000d2                                      B61Ma cn30
Fbcdmp0200s000d2                                      B61Ma cn30
Fbcdmp0203s000d2                                      B61Ma cn30
Fbcdmp4220m000d2                                      B61Ma cn30
Fbcdmp4520m000d2                                      B61Ma cn30
Fbcdmp5100m000d2                                      B61Ma cn30
Fbcdmp5106m000d2                                      B61Ma cn30
Fbcdmp5201m000d2                                      B61Ma cn30
Fbcdmp5300m000d2                                      B61Ma cn30
Fbcdmp5301m000d2                                      B61Ma cn30
Fbcdmp5401m000d2                                      B61Ma cn30
Fbcdmp5404m000d2                                      B61Ma cn30
Fbcdmp5406m000d2                                      B61Ma cn30
Fbcdmp5500m000d2                                      B61Ma cn30
Fbcdmp5501m000d2                                      B61Ma cn30
Fbcdmp5503m000d2                                      B61Ma cn30
Fbcdmp6400m000d2                                      B61Ma cn30
Fbcdmp8101m000d2                                      B61Ma cn30
Fbcdmp8201s000d2                                      B61Ma cn30
Fbcdmp8201s002d2                                      B61Ma cn30
Fbcdmp8203m000d2                                      B61Ma cn30
Fbcdmp8502m000d2                                      B61Ma cn30
Fbcdmp8503m000d2                                      B61Ma cn30
Fbcdmp8503s002d2                                      B61Ma cn30
Fbcdmp8506s000d2                                      B61Ma cn30
Fbcdmp8507s000d2                                      B61Ma cn30
Fbcdmp8508s000d2                                      B61Ma cn30
Fbcdmp8570m000d2                                      B61Ma cn30
Fbcdmp8571m000d2                                      B61Ma cn30
Fbcdmp8572m000d2                                      B61Ma cn30
Fbcdmp9087m000d2                                      B61Ma cn30
Fbcdmp9100m000d2                                      B61Ma cn30
Fbcdmp9188m000d2                                      B61Ma cn30
Fbcdmp9189m000d2                                      B61Ma cn30
Fbcdmp9190m000d2                                      B61Ma cn30
Fbcdmp9191m000d2                                      B61Ma cn30
Fbcdmp9288m000d2                                      B61Ma cn30
Fbcdmp9291m100d2                                      B61Ma cn30
Fbcdmp9291m200d2                                      B61Ma cn30
Fbcdmp9442m000d2                                      B61Ma cn30
Fbcdmp9585m000d2                                      B61Ma cn30
Fbcdmp9599m000d2                                      B61Ma cn30
Fbcdmpdebugd   2                                      B61Ma cn30
Fbcgct0100m000d2                                      B61Ma cn30
Fbcgct3101m000d2                                      B61Ma cn30
Fbcgct3102m000d2                                      B61Ma cn30
Fbcgct3103m000d2                                      B61Ma cn30
Fbcgct3105m000d2                                      B61Ma cn30
Fbcgct4500m000d2                                      B61Ma cn30
Fbcgct4501m000d2                                      B61Ma cn30
Fbcgct4502m000d2                                      B61Ma cn30
Fbcgct6100m000d2                                      B61Ma cn30
Fbcgct6100s100d2                                      B61Ma cn30
Fbcgct6101m000d2                                      B61Ma cn30
Fbcgct7186m000d2                                      B61Ma cn30
Fbcgct7286m000d2                                      B61Ma cn30
Fbcgct8188m000d2                                      B61Ma cn30
Fbcgct8189m000d2                                      B61Ma cn30
Fbcgct8283m000d2                                      B61Ma cn30
Fbcgct8288m000d2                                      B61Ma cn30
Fbcgct8289m000d2                                      B61Ma cn30
Fbcgct8489m000d2                                      B61Ma cn30
Fbcgct9188m000d2                                      B61Ma cn30
Fbcgct9189m000d2                                      B61Ma cn30
Fbcgct9285m000d2                                      B61Ma cn30
Fbcgct9289m000d2                                      B61Ma cn30
Fbcgcteasym000d2                                      B61Ma cn30
Fbcgctmysqld   2                                      B61Ma cn30
Fbcgctoracled  2                                      B61Ma cn30
Fbcgen9200m000d2                                      B61Ma cn30
Fbcldr9100m000d2                                      B61Ma cn30
Fbcrun0000m000d2                                      B61Ma cn30
Fbcrun0207m000d2                                      B61Ma cn30
Fbcrun0507m000d2                                      B61Ma cn30
Fbcrun8288m000d2                                      B61Ma cn30
Fbcrun8588m000d2                                      B61Ma cn30
Fbcrun9599m000d2                                      B61Ma cn30
Fbcruntdsls400d2                                      B61Ma cn30
Mbccnvcodalign12                                      B61Ma cn30
Mbccnvreport  12                                      B61Ma cn30
Mbccnvtrunutl 12                                      B61Ma cn30
Mbcdmpesetup  12                                      B61Ma cn30
Mbcdmpprocedur12                                      B61Ma cn30
Mbcdmpprocess 12                                      B61Ma cn30
Mbcdmpreports 12                                      B61Ma cn30
Mbcdmpsimulate12                                      B61Ma cn30
Mbcdmputility212                                      B61Ma cn30
Mbcgctconver  12                                      B61Ma cn30
Mbcgctparam   12                                      B61Ma cn30
Mbcgctpreconv 12                                      B61Ma cn30
Mbcldrauto    12                                      B61Ma cn30
Mbcldrconvert 12                                      B61Ma cn30
Mbcldrdatavali12                                      B61Ma cn30
Mbcldrmigwizar12                                      B61Ma cn30
Mbcldrprocess 12                                      B61Ma cn30
Mbcldrsetup   12                                      B61Ma cn30
Mbcldrutility 12                                      B61Ma cn30
Mbcldrutility112                                      B61Ma cn30
